@@ -16,9 +16,8 @@
 
 """Tests for the osutils wrapper."""
 
-from __future__ import absolute_import, division
-
 import errno
+from io import BytesIO
 import os
 import select
 import socket
@@ -33,11 +32,6 @@ from .. import (
     trace,
     win32utils,
     )
-from ..sixish import (
-    BytesIO,
-    PY3,
-    text_type,
-    )
 from . import (
     features,
     file_utils,
@@ -405,7 +399,7 @@ class TestDateTime(tests.TestCase):
         self.assertRaises(osutils.UnsupportedTimezoneFormat,
                           osutils.format_date, 0, timezone='foo')
         self.assertIsInstance(osutils.format_date(0), str)
-        self.assertIsInstance(osutils.format_local_date(0), text_type)
+        self.assertIsInstance(osutils.format_local_date(0), str)
         # Testing for the actual value of the local weekday without
         # duplicating the code from format_date is difficult.
         # Instead blackbox.test_locale should check for localized
@@ -824,50 +818,6 @@ class TestSafeUtf8(tests.TestCase):
                           osutils.safe_utf8, b'\xbb\xbb')
 
 
-class TestSafeRevisionId(tests.TestCase):
-
-    def test_from_ascii_string(self):
-        # this shouldn't give a warning because it's getting an ascii string
-        self.assertEqual(b'foobar', osutils.safe_revision_id(b'foobar'))
-
-    def test_from_unicode_string_ascii_contents(self):
-        self.assertRaises(TypeError,
-                          osutils.safe_revision_id, u'bargam')
-
-    def test_from_unicode_string_unicode_contents(self):
-        self.assertRaises(TypeError,
-                          osutils.safe_revision_id, u'bargam\xae')
-
-    def test_from_utf8_string(self):
-        self.assertEqual(b'foo\xc2\xae',
-                         osutils.safe_revision_id(b'foo\xc2\xae'))
-
-    def test_none(self):
-        """Currently, None is a valid revision_id"""
-        self.assertEqual(None, osutils.safe_revision_id(None))
-
-
-class TestSafeFileId(tests.TestCase):
-
-    def test_from_ascii_string(self):
-        self.assertEqual(b'foobar', osutils.safe_file_id(b'foobar'))
-
-    def test_from_unicode_string_ascii_contents(self):
-        self.assertRaises(TypeError, osutils.safe_file_id, u'bargam')
-
-    def test_from_unicode_string_unicode_contents(self):
-        self.assertRaises(TypeError,
-                          osutils.safe_file_id, u'bargam\xae')
-
-    def test_from_utf8_string(self):
-        self.assertEqual(b'foo\xc2\xae',
-                         osutils.safe_file_id(b'foo\xc2\xae'))
-
-    def test_none(self):
-        """Currently, None is a valid revision_id"""
-        self.assertEqual(None, osutils.safe_file_id(None))
-
-
 class TestSendAll(tests.TestCase):
 
     def test_send_with_disconnected_socket(self):
@@ -947,10 +897,7 @@ class TestWin32Funcs(tests.TestCase):
                          osutils._win32_pathjoin('path/to/', 'foo'))
 
     def test_pathjoin_late_bugfix(self):
-        if sys.version_info < (2, 7, 6):
-            expected = '/foo'
-        else:
-            expected = 'C:/foo'
+        expected = 'C:/foo'
         self.assertEqual(expected,
                          osutils._win32_pathjoin('C:/path/to/', '/foo'))
         self.assertEqual(expected,
@@ -1409,11 +1356,11 @@ class TestWalkDirs(tests.TestCaseInTempDir):
         # all abspaths are Unicode, and encode them back into utf8.
         for dirdetail, dirblock in osutils._walkdirs_utf8('.'):
             self.assertIsInstance(dirdetail[0], bytes)
-            if isinstance(dirdetail[1], text_type):
+            if isinstance(dirdetail[1], str):
                 dirdetail = (dirdetail[0], dirdetail[1].encode('utf8'))
                 dirblock = [list(info) for info in dirblock]
                 for info in dirblock:
-                    self.assertIsInstance(info[4], text_type)
+                    self.assertIsInstance(info[4], str)
                     info[4] = info[4].encode('utf8')
             new_dirblock = []
             for info in dirblock:
@@ -1740,10 +1687,7 @@ class TestSetUnsetEnv(tests.TestCase):
                 % (osutils.get_user_encoding(),))
 
         osutils.set_or_unset_env('BRZ_TEST_ENV_VAR', uni_val)
-        if PY3:
-            self.assertEqual(uni_val, os.environ.get('BRZ_TEST_ENV_VAR'))
-        else:
-            self.assertEqual(env_val, os.environ.get('BRZ_TEST_ENV_VAR'))
+        self.assertEqual(uni_val, os.environ.get('BRZ_TEST_ENV_VAR'))
 
     def test_unset(self):
         """Test that passing None will remove the env var"""
@@ -2004,13 +1948,9 @@ class TestFailedToLoadExtension(tests.TestCase):
     def test_failure_to_load(self):
         self._try_loading()
         self.assertLength(1, osutils._extension_load_failures)
-        if PY3:
-            self.assertEqual(
-                osutils._extension_load_failures[0],
-                "No module named 'breezy._fictional_extension_py'")
-        else:
-            self.assertEqual(osutils._extension_load_failures[0],
-                             "No module named _fictional_extension_py")
+        self.assertEqual(
+            osutils._extension_load_failures[0],
+            "No module named 'breezy._fictional_extension_py'")
 
     def test_report_extension_load_failures_no_warning(self):
         self.assertTrue(self._try_loading())
@@ -2153,55 +2093,21 @@ class TestCreationOps(tests.TestCaseInTempDir):
         self.assertEqual(self.gid, s.st_gid)
 
 
-class TestPathFromEnviron(tests.TestCase):
-
-    def test_is_unicode(self):
-        self.overrideEnv('BRZ_TEST_PATH', './anywhere at all/')
-        path = osutils.path_from_environ('BRZ_TEST_PATH')
-        self.assertIsInstance(path, text_type)
-        self.assertEqual(u'./anywhere at all/', path)
-
-    def test_posix_path_env_ascii(self):
-        self.overrideEnv('BRZ_TEST_PATH', '/tmp')
-        home = osutils._posix_path_from_environ('BRZ_TEST_PATH')
-        self.assertIsInstance(home, text_type)
-        self.assertEqual(u'/tmp', home)
-
-    def test_posix_path_env_unicode(self):
-        self.requireFeature(features.ByteStringNamedFilesystem)
-        self.overrideEnv('BRZ_TEST_PATH', '/home/\xa7test')
-        self.overrideAttr(osutils, "_fs_enc", "iso8859-1")
-        self.assertEqual(u'/home/\xa7test',
-                         osutils._posix_path_from_environ('BRZ_TEST_PATH'))
-        osutils._fs_enc = "iso8859-5"
-        if PY3:
-            # In Python 3, os.environ returns unicode.
-            self.assertEqual(u'/home/\xa7test',
-                             osutils._posix_path_from_environ('BRZ_TEST_PATH'))
-        else:
-            self.assertEqual(u'/home/\u0407test',
-                             osutils._posix_path_from_environ('BRZ_TEST_PATH'))
-            osutils._fs_enc = "utf-8"
-            self.assertRaises(
-                errors.BadFilenameEncoding,
-                osutils._posix_path_from_environ, 'BRZ_TEST_PATH')
-
-
 class TestGetHomeDir(tests.TestCase):
 
     def test_is_unicode(self):
         home = osutils._get_home_dir()
-        self.assertIsInstance(home, text_type)
+        self.assertIsInstance(home, str)
 
     def test_posix_homeless(self):
         self.overrideEnv('HOME', None)
         home = osutils._get_home_dir()
-        self.assertIsInstance(home, text_type)
+        self.assertIsInstance(home, str)
 
     def test_posix_home_ascii(self):
         self.overrideEnv('HOME', '/home/test')
         home = osutils._posix_get_home_dir()
-        self.assertIsInstance(home, text_type)
+        self.assertIsInstance(home, str)
         self.assertEqual(u'/home/test', home)
 
     def test_posix_home_unicode(self):
@@ -2210,22 +2116,15 @@ class TestGetHomeDir(tests.TestCase):
         self.overrideAttr(osutils, "_fs_enc", "iso8859-1")
         self.assertEqual(u'/home/\xa7test', osutils._posix_get_home_dir())
         osutils._fs_enc = "iso8859-5"
-        if PY3:
-            # In python 3, os.environ returns unicode
-            self.assertEqual(u'/home/\xa7test', osutils._posix_get_home_dir())
-        else:
-            self.assertEqual(u'/home/\u0407test',
-                             osutils._posix_get_home_dir())
-            osutils._fs_enc = "utf-8"
-            self.assertRaises(errors.BadFilenameEncoding,
-                              osutils._posix_get_home_dir)
+        # In python 3, os.environ returns unicode
+        self.assertEqual(u'/home/\xa7test', osutils._posix_get_home_dir())
 
 
 class TestGetuserUnicode(tests.TestCase):
 
     def test_is_unicode(self):
         user = osutils.getuser_unicode()
-        self.assertIsInstance(user, text_type)
+        self.assertIsInstance(user, str)
 
     def envvar_to_override(self):
         if sys.platform == "win32":
@@ -2247,10 +2146,7 @@ class TestGetuserUnicode(tests.TestCase):
                 % (osutils.get_user_encoding(),))
         uni_username = u'jrandom' + uni_val
         encoded_username = uni_username.encode(ue)
-        if PY3:
-            self.overrideEnv(self.envvar_to_override(), uni_username)
-        else:
-            self.overrideEnv(self.envvar_to_override(), encoded_username)
+        self.overrideEnv(self.envvar_to_override(), uni_username)
         self.assertEqual(uni_username, osutils.getuser_unicode())
 
 
@@ -2316,32 +2212,6 @@ class TestFindExecutableInPath(tests.TestCase):
             osutils.find_executable_on_path('THIS SHOULD NOT EXIST') is None)
 
 
-class TestEnvironmentErrors(tests.TestCase):
-    """Test handling of environmental errors"""
-
-    def test_is_oserror(self):
-        self.assertTrue(osutils.is_environment_error(
-            OSError(errno.EINVAL, "Invalid parameter")))
-
-    def test_is_ioerror(self):
-        self.assertTrue(osutils.is_environment_error(
-            IOError(errno.EINVAL, "Invalid parameter")))
-
-    def test_is_socket_error(self):
-        self.assertTrue(osutils.is_environment_error(
-            socket.error(errno.EINVAL, "Invalid parameter")))
-
-    def test_is_select_error(self):
-        self.assertTrue(osutils.is_environment_error(
-            select.error(errno.EINVAL, "Invalid parameter")))
-
-    def test_is_pywintypes_error(self):
-        self.requireFeature(features.pywintypes)
-        import pywintypes
-        self.assertTrue(osutils.is_environment_error(
-            pywintypes.error(errno.EINVAL, "Invalid parameter", "Caller")))
-
-
 class SupportsExecutableTests(tests.TestCaseInTempDir):
 
     def test_returns_bool(self):
@@ -2374,7 +2244,7 @@ class GetFsTypeTests(tests.TestCaseInTempDir):
 
     def test_returns_string_or_none(self):
         ret = osutils.get_fs_type(self.test_dir)
-        self.assertTrue(isinstance(ret, text_type) or ret is None)
+        self.assertTrue(isinstance(ret, str) or ret is None)
 
     def test_returns_most_specific(self):
         self.overrideAttr(
